import { Modal } from "antd";
import { inject, observer } from "mobx-react";
import { useEffect, useRef, useState } from "react";
import Config from "@/util/config";
import EasyPlayer from "../videoTow";
import { Store } from "antd/es/form/interface";
const WhichVideo = (props:Store) => {
  const { homeStore } = props;
  const [isModalOpen, setIsModalOpen] = useState<boolean>(false);
  const [deviceList, setDeviceList] = useState<Array<any>>([]);
  const [channelList, setChannelList] = useState<Array<any>>([]);
  const deviceId = useRef<number>(0);
  const channelId = useRef<number>(0);
  const [videoUrl, setVideoUrl] = useState<string | null>("");
  let timer: any = null;

  const openDispatch = async () => {
    setIsModalOpen(true);
    let req = await homeStore.getVideoUrlList();
    setDeviceList(req.EasyDarwin.Body.Devices);
  };
  const getChannerList = async (id) => {
    let reqs = await homeStore.getChannerUrlList(id);
    setChannelList(reqs.EasyDarwin.Body.Channels);
  };
  const fetchUrl = async (did, cid) => {
    try {
      const reqs = await homeStore.getChannerStrem(did, cid);
      if (!reqs.EasyDarwin) return;
      const url = Config.videoApis + reqs.EasyDarwin.Body.URL;
      setVideoUrl(url);
    } catch (error) {
      console.error("Error fetching video URL:", error);
    }
  };
  const getUrl = async () => {
    if (timer) {
      clearInterval(timer);
    }
    fetchUrl(deviceId.current, channelId.current);
    timer = setInterval(() => {
      console.log();
      fetchUrl(deviceId.current, channelId.current);
    }, 35000);
  };
  useEffect(() => {
    return () => {
      clearInterval(timer);
    };
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  return (
    <>
      <span onClick={openDispatch}> 视频查看</span>
      <Modal
        title={"视频查看"}
        className="owner_model"
        width={"80%"}
        height={"650px"}
        centered
        open={isModalOpen}
        afterClose={() => {
          setDeviceList([]);
          setChannelList([]);
          setVideoUrl(null);
          deviceId.current = 0;
        }}
        onOk={() => {}}
        footer={null}
        onCancel={() => {
          setIsModalOpen(false);
        }}
      >
        <div>
          <div style={{ display: "flex" }}>
            <div
              style={{
                overflowY: "scroll",
                height: "550px",
                width: "240px",
                border: "1px solid #ccc",
                padding: "10px",
              }}
            >
              {deviceList.map((item, index) => {
                return (
                  <div
                    key={index}
                    style={{ cursor: "pointer" }}
                    onClick={() => {
                      deviceId.current = item.DeviceID;
                      getChannerList(item.DeviceID);
                    }}
                  >
                    <p
                      style={{
                        color:
                          deviceId.current === item.DeviceID
                            ? "yellow"
                            : "#fff",
                      }}
                    >
                      {item.DeviceName}
                    </p>
                  </div>
                );
              })}
            </div>
            <div style={{ width: "20px" }}></div>
            <div
              style={{
                height: "550px",
                overflow: "scroll",
                width: "240px",
                border: "1px solid #ccc",
                marginBottom: "20px",
                padding: "10px",
              }}
            >
              {channelList.map((item, index) => {
                return (
                  <div
                    key={index}
                    style={{ cursor: "pointer" }}
                    onClick={() => {
                      channelId.current = item.ChannelID;
                      getUrl();
                    }}
                  >
                    <p
                      style={{
                        color:
                          channelId.current === item.ChannelID
                            ? "yellow"
                            : "#fff",
                      }}
                    >
                      {item.Name}
                    </p>
                  </div>
                );
              })}
            </div>
            <div style={{ width: "20px" }}></div>
            <div className="video" style={{ width: "100%", height: "550px" }}>
              {<EasyPlayer url={videoUrl} />}
            </div>
          </div>
        </div>
      </Modal>
    </>
  );
};

// export default WhichVideo;
export default inject("homeStore")(observer(WhichVideo));
